/****************** DATA CONSTRUCTION for GVAR *********************
#   ORDER OF 8 MARKETS:
--------------------------------------
1	DEM?USD 
2	GBP/USD
3	JPY/USD
4	CHF/USD
5	FRF/USD
6	BEF/USD
7	ITL/USD
8	NLG/USD
*******************************************************************/

new; 
cls;
time;

/* STEP 1: IMPORT WEIGHTING MATRIX */

wei = xlsreadm("DATA_EXCH", "b22:i29", 9, "");
"Finish STEP 1: Importing Weighting Matrix";

/* STEP 2: IMPORT DATA for 8 MARKETS */

range1 = "b2:d83";
obs = 82;
dcard = 2; @ 1 obs lost due to differencing @

i = 1;
do until i > 8;

   ctry = xlsreadm("DATA_EXCH", range1, i, "");
   
   p = ctry[.,1]; of = ctry[.,2]; cof = ctry[.,3]; 
   
   p = ln(p); /* Exchange Rate */

   of = of./1000; 
   cof = cof./1000; 



ctryi = p~of~cof; 
   
if     i eq 1; ctry1 = ctryi; 
elseif i eq 2; ctry2 = ctryi; 
elseif i eq 3; ctry3 = ctryi; 
elseif i eq 4; ctry4 = ctryi; 
elseif i eq 5; ctry5 = ctryi; 
elseif i eq 6; ctry6 = ctryi; 
elseif i eq 7; ctry7 = ctryi; 
elseif i eq 8; ctry8 = ctryi; 
endif;
    i = i + 1; 
endo;
"Finish STEP 2: Importing Data for Each Market";



/* STEP 3: CREATE WORLD VARIABLES */
/* 1. DEM ------------------------------------------*/ 
p1 = ctry1[.,1]; of1 = ctry1[.,2]; cof1 = ctry1[.,3]; 

/* 2. GBP ------------------------------------------*/ 
p2 = ctry2[.,1]; of2 = ctry2[.,2]; cof2 = ctry2[.,3]; 

/* 3. JPY ------------------------------------------*/ 
p3 = ctry3[.,1]; of3 = ctry3[.,2]; cof3 = ctry3[.,3]; 

/* 4. CHF ------------------------------------------*/ 
p4 = ctry4[.,1]; of4 = ctry4[.,2]; cof4 = ctry4[.,3]; 

/* 5. FRF ------------------------------------------*/ 
p5 = ctry5[.,1]; of5 = ctry5[.,2]; cof5 = ctry5[.,3]; 

/* 6. BEF ------------------------------------------*/ 
p6 = ctry6[.,1]; of6 = ctry6[.,2]; cof6 = ctry6[.,3]; 

/* 7. ITL ------------------------------------------*/ 
p7 = ctry7[.,1]; of7 = ctry7[.,2]; cof7 = ctry7[.,3]; 

/* 8. NLG ------------------------------------------*/ 
p8 = ctry8[.,1]; of8 = ctry8[.,2]; cof8 = ctry8[.,3]; 

wp = p1~p2~p3~p4~p5~p6~p7~p8;
wof = of1~of2~of3~of4~of5~of6~of7~of8;
wcof = cof1~cof2~cof3~cof4~cof5~cof6~cof7~cof8;

j = 1;

do until j > 8;

ps = wp.*wei[j,.];  ps = sumr(ps);
ofs = wof.*wei[j,.];  ofs = sumr(ofs);
cofs = wcof.*wei[j,.];  cofs = sumr(cofs);


if     j eq 1;   ctry1s = ps~ofs~cofs;  
elseif j eq 2;   ctry2s = ps~ofs~cofs;
elseif j eq 3;   ctry3s = ps~ofs~cofs;
elseif j eq 4;   ctry4s = ps~ofs~cofs;
elseif j eq 5;   ctry5s = ps~ofs~cofs; 
elseif j eq 6;   ctry6s = ps~ofs~cofs;
elseif j eq 7;   ctry7s = ps~ofs~cofs;
elseif j eq 8;   ctry8s = ps~ofs~cofs;
endif;

    j = j + 1;

endo;
"Finish STEP 3: Constructing Weakly Exo Foreign Variable Construction ";

/* STEP 4: EXPORT DATA for 8 MARKETS */
region1 = ctry1~ctry1s;      
region2 = ctry2~ctry2s;      
region3 = ctry3~ctry3s;      
region4 = ctry4~ctry4s;      
region5 = ctry5~ctry5s;      
region6 = ctry6~ctry6s;      
region7 = ctry7~ctry7s;      
region8 = ctry8~ctry8s; 

output1 = xlswritem(region1, "EXCH8", "b2", 1, "");
output2 = xlswritem(region2, "EXCH8", "b2", 2, "");
output3 = xlswritem(region3, "EXCH8", "b2", 3, "");
output4 = xlswritem(region4, "EXCH8", "b2", 4, "");
output5 = xlswritem(region5, "EXCH8", "b2", 5, "");
output6 = xlswritem(region6, "EXCH8", "b2", 6, "");
output7 = xlswritem(region7, "EXCH8", "b2", 7, "");
output8 = xlswritem(region8, "EXCH8", "b2", 8, "");

output8 = xlswritem(wei, "EXCH8", "b2", 9, "");

/************ HEADERS **************/

header = {"time" "p" "of" "cof" "ps" "ofs" "cofs"};
aaa = xlsreadsa("DATA_EXCH", "a2:a83", 1, "");

jj = 1; 

do until jj > 8;

    colhead = xlswritesa(header, "EXCH8", "a1", jj,"");
    rowhead = xlswritesa(aaa, "EXCH8", "a2", jj,"");

    jj = jj + 1;

endo;
"Finish STEP 4: Exporting Data for Each Market and Weight Matrix";
"Finished.";
time;