// This program collects the bootstrapped bilateral connectedness measures among:
// 		1. Variables
// 		2. Markets 
// 		3. Leading-Recipient Hypothesis Test
// and cross-tab them into connectedness tables at different horizons (each sheet is one horizon).

new;  cls; library pgraph; graphset; time;

m = 16;
n = 8;
hor = 40;

range0m = "b4:bm44"; // Mean
range1m = "dz4:gk44"; // Lower 90%
range2m = "gl4:iw44"; // Upper 90%

range0v = "b4:iw44"; // Mean
range1v = "st4:aco44"; // Lower 90%
range2V = "acp4:amk44"; // Upper 90%

workfileM = "BOOT_MARKET_CONNECT_BI.xlsx";
workfileT = "BOOT_LR_HYPOTHESIS_TEST.xlsx";
workfileV = "BOOT_VARIABLE_CONNECT_BI.xlsx";

    ALLresult0m = xlsreadm(workfileM,range0m,1,""); @ Bootstrapped Bilateral Connectedness Among Market: Mean @
	ALLresult1m = xlsreadm(workfileM,range1m,1,""); @ Bootstrapped Bilateral Connectedness Among Market @
	ALLresult2m = xlsreadm(workfileM,range2m,1,""); @ Bootstrapped Bilateral Connectedness Among Market @

    ALLresult0t = xlsreadm(workfileT,range0m,1,""); @ Bootstrapped Bilateral Connectedness Among Market: Mean @
	ALLresult1t = xlsreadm(workfileT,range1m,1,""); @ Bootstrapped Bilateral Connectedness Among Market @
	ALLresult2t = xlsreadm(workfileT,range2m,1,""); @ Bootstrapped Bilateral Connectedness Among Market @

    ALLresult0v = xlsreadm(workfileV,range0v,1,""); @ Bootstrapped Bilateral Connectedness Among Market: Mean @
	ALLresult1v = xlsreadm(workfileV,range1v,1,""); @ Bootstrapped Bilateral Connectedness Among Market @
	ALLresult2v = xlsreadm(workfileV,range2v,1,""); @ Bootstrapped Bilateral Connectedness Among Market @
	
h = 1;
do until h > hor;

"Horizon" h;

// Variable
resulth0v = ALLresult0v[h,.];
resulth1v = ALLresult1v[h,.];
resulth2V = ALLresult2v[h,.];

resulth_table0v = reshape(resulth0v,m,m);
resulth_table1v = reshape(resulth1v,m,m);
resulth_table2v = reshape(resulth2v,m,m);

out0v = xlswritem(resulth_table0V,"GVAR_var_connectedness_BOOT_RESULTS.xlsx","c3",h,"");
out1v = xlswritem(resulth_table1v,"GVAR_var_connectedness_BOOT_RESULTS.xlsx","c25",h,"");
out2v = xlswritem(resulth_table2v,"GVAR_var_connectedness_BOOT_RESULTS.xlsx","c47",h,"");


// Market 
resulth0m = ALLresult0m[h,.];
resulth1m = ALLresult1m[h,.];
resulth2m = ALLresult2m[h,.];

resulth_table0m = reshape(resulth0m,n,n);
resulth_table1m = reshape(resulth1m,n,n);
resulth_table2m = reshape(resulth2m,n,n);

out0m = xlswritem(resulth_table0m,"GVAR_mar_connectedness_BOOT_RESULTS.xlsx","b2",h,"");
out1m = xlswritem(resulth_table1m,"GVAR_mar_connectedness_BOOT_RESULTS.xlsx","b15",h,"");
out2m = xlswritem(resulth_table2m,"GVAR_mar_connectedness_BOOT_RESULTS.xlsx","b28",h,"");


// Leading-Recipient Hypothesis Test
resulth0t = ALLresult0t[h,.];
resulth1t = ALLresult1t[h,.];
resulth2t = ALLresult2t[h,.];

resulth_table0t = reshape(resulth0t,n,n);
resulth_table1t = reshape(resulth1t,n,n);
resulth_table2t = reshape(resulth2t,n,n);

out0t = xlswritem(resulth_table0t,"GVAR_LR_HYPOTHESIS_BOOT_RESULTS.xlsx","b2",h,"");
out1t = xlswritem(resulth_table1t,"GVAR_LR_HYPOTHESIS_BOOT_RESULTS.xlsx","b15",h,"");
out2t = xlswritem(resulth_table2t,"GVAR_LR_HYPOTHESIS_BOOT_RESULTS.xlsx","b28",h,"");


h = h + 1;

endo;

"Done!";
time;
	
end;	